==> xt-miniprogram-ui-1.0.14.tgz: package/libs/xt-uploader/index.js <==
// src/xt-uploader/index.js
const utils = require("./utils");
Component({
	/**
	 * 组件的属性列表
	 */
	properties: {
		title: {
			type: String,
			value: "",
		},
		fileList: {
			type: Array,
			value: [],
		},
		max: {
			type: Number,
			value: 9,
		},
		uploadDesc: {
			type: String,
			value: "",
		},
		// ["album", "camera"]
		sourceType: {
			type: Array,
			value: ["album", "camera"],
		},
		customUpload: {
			type: Boolean,
			value: false,
		},
		disabled: {
			type: Boolean,
			value: false,
		},
		uploadApi: {
			type: Object,
			value: {},
		},
	},

	/**
	 * 组件的初始数据
	 */
	data: {},

	/**
	 * 组件的方法列表
	 */
	methods: {
		// 预览
		onPreviewImage(e) {
			const url = e.target.dataset.url;
			// const index = e.target.dataset.index;
			wx.previewImage({
				urls: this.properties.fileList,
				current: url,
			});
		},
		// 删除
		onDelete(e) {
			const url = e.currentTarget.dataset.url;
			const index = e.currentTarget.dataset.index;
			this.properties.fileList.splice(index, 1);
			this.triggerEvent("delete", {
				fileList: this.properties.fileList,
				url,
				index,
			});
		},
		// 上传成功
		onUploadSuccess(files, url) {
			this.triggerEvent("upload", { fileList: files, url });
		},
		// 上传失败
		onUploadError(errMsg) {
			this.triggerEvent("error", { errMsg });
		},
		// 点击上传
		startTakePhoto() {
			const _this = this;
			const { customUpload, uploadApi, max, sourceType, fileList } =
				this.properties;
			if (customUpload) {
				this.triggerEvent("upload", {});
				return;
			}
			if (!uploadApi || !uploadApi.url) {
				wx.showToast({
					title: "请传入上传接口",
					icon: "error",
				});
				return;
			}
			wx.chooseMedia({
				count: max - fileList.length,
				mediaType: ["image"],
				sizeType: ["compressed"],
				sourceType,
				success(res) {
					console.log(res, "0000");
					// tempFilePath可以作为img标签的src属性显示图片
					const tempFilePaths = res.tempFiles;
					if (Array.isArray(tempFilePaths) && tempFilePaths.length) {
						Promise.allSettled(
							tempFilePaths.map((temp) =>
								_this.uploadImage_v(temp.tempFilePath)
							)
						).then((uploadRes) => {
							wx.hideLoading();
							console.log("----uploadRes", uploadRes);
							// 上传成功
							const successUrls = uploadRes
								.filter((result) => result.status == "fulfilled")
								.map((result) => result.value);
							if (successUrls.length) {
								const files = fileList.concat(successUrls);
								_this.onUploadSuccess(files, successUrls);
							}
							// 上传失败
							const errorList = uploadRes.filter(
								(result) => result.status == "rejected"
							);
							if (errorList.length) {
								_this.onUploadError(errorList[0].value);
							}
						});
					}
				},
				fail(error) {
					_this.onUploadError(error && error.errMsg);
					console.log("-----选取失败", error && error.errMsg);
				},
			});
		},
		// 上传文件
		uploadImage_v(filePaths) {
			return new Promise((resolve, reject) => {
				const { url, fileDir, ...header } = this.properties.uploadApi;
				wx.showLoading("上传中");
				utils.newHttp(
					url,
					"GET",
					{
						dir: fileDir || "microComponents",
					},
					header,
					(res) => {
						const { host, signature, accessKeyId, policy, dir } = res.data;
						if (host) {
							let path = filePaths;
							let name = utils.random_string(32) + utils.get_suffix(path);
							wx.uploadFile({
								url: host,
								filePath: filePaths,
								name: "file",
								formData: {
									key: dir + "/" + name,
									policy,
									success_action_status: "200",
									OSSAccessKeyId: accessKeyId,
									signature,
								},
								header: {
									"Content-Type": "multipart/form-data",
								},
								success: (res) => {
									if (res.statusCode == 200) {
										let url = host + dir + "/" + name;
										resolve(url);
										// fileList.push(url);
										// _this.onUploadSuccess(url);
										// wx.showToast({
										// 	icon: "success",
										// 	title: "上传成功",
										// });
									}
								},
								fail: (err) => {
									reject(err.errMsg || "网络错误，请重试");
									// _this.onUploadError(err.errMsg || "网络错误，请重试");
									// wx.showToast({
									// 	icon: "error",
									// 	title: err.errMsg || "网络错误，请重试",
									// });
								},
							});
						} else {
							reject(res.message);
							// _this.onUploadError(res.message);
						}
					}
				);
			});
		},
	},
});

==> xt-miniprogram-ui-1.0.15.tgz: package/libs/xt-uploader/index.js <==
// src/xt-uploader/index.js
const utils = require("./utils");
Component({
	/**
	 * 组件的属性列表
	 */
	properties: {
		title: {
			type: String,
			value: "",
		},
		fileList: {
			type: Array,
			value: [],
		},
		max: {
			type: Number,
			value: 9,
		},
		uploadDesc: {
			type: String,
			value: "",
		},
		// ["album", "camera"]
		sourceType: {
			type: Array,
			value: ["camera"],
		},
		customUpload: {
			type: Boolean,
			value: false,
		},
		disabled: {
			type: Boolean,
			value: false,
		},
		uploadApi: {
			type: Object,
			value: {},
		},
	},

	/**
	 * 组件的初始数据
	 */
	data: {},

	/**
	 * 组件的方法列表
	 */
	methods: {
		// 预览
		onPreviewImage(e) {
			const url = e.target.dataset.url;
			// const index = e.target.dataset.index;
			wx.previewImage({
				urls: this.properties.fileList,
				current: url,
			});
		},
		// 删除
		onDelete(e) {
			const url = e.currentTarget.dataset.url;
			const index = e.currentTarget.dataset.index;
			this.properties.fileList.splice(index, 1);
			this.triggerEvent("delete", {
				fileList: this.properties.fileList,
				url,
				index,
			});
		},
		// 上传成功
		onUploadSuccess(url) {
			this.triggerEvent("upload", { fileList: this.properties.fileList, url });
		},
		// 上传失败
		onUploadError(errMsg) {
			this.triggerEvent("error", { errMsg });
		},
		// 点击上传
		startTakePhoto() {
			const _this = this;
			if (this.properties.customUpload) {
				this.triggerEvent("upload", {});
				return;
			}
			const uploadApi = this.properties.uploadApi;
			if (!uploadApi || !uploadApi.url) {
				wx.showToast({
					title: "请传入上传接口",
					icon: "error",
				});
				return;
			}
			wx.chooseMedia({
				count: 1,
				mediaType: ["image"],
				sizeType: ["compressed"],
				sourceType: this.properties.sourceType,
				success(res) {
					console.log(res, "0000");
					// tempFilePath可以作为img标签的src属性显示图片
					const tempFilePaths = res.tempFiles[0].tempFilePath;
					_this.uploadImage_v(tempFilePaths);
				},
				fail(error) {
					_this.onUploadError(error && error.errMsg);
					console.log("-----选取失败", error && error.errMsg);
				},
			});
		},
		// 上传文件
		uploadImage_v(filePaths) {
			const { url, fileDir, ...header } = this.properties.uploadApi;
			let _this = this;
			const { fileList } = _this.properties;
			wx.showLoading("图片上传中");
			utils.newHttp(
				url,
				"GET",
				{
					dir: fileDir || "microComponents",
				},
				header,
				(res) => {
					const { host, signature, accessKeyId, policy, dir } = res.data;
					if (host) {
							let path = filePaths;
							let name = utils.random_string(32) + utils.get_suffix(path);
							wx.uploadFile({
								url: host,
								filePath: filePaths,
								name: "file",
								formData: {
									key: dir + "/" + name,
									policy,
									success_action_status: "200",
									OSSAccessKeyId: accessKeyId,
									signature,
								},
								header: {
									"Content-Type": "multipart/form-data",
								},
								success: (res) => {
									if (res.statusCode == 200) {
										let url = host + dir + "/" + name;
										fileList.push(url);
										_this.onUploadSuccess(url);
										wx.showToast({
											icon: "success",
											title: "上传成功",
										});
									}
								},
								fail: (err) => {
									_this.onUploadError(err.errMsg || "网络错误，请重试");
									wx.showToast({
										icon: "error",
										title: err.errMsg || "网络错误，请重试",
									});
								},
							});
					} else {
						_this.onUploadError(res.message);
					}
				}
			);
		},
	},
});
